@@ -2,6 +2,7 @@ import os
 import sqlite3
 import pandas as pd
 import duckdb
+from pathlib import Path
 
 class DatabaseManager:
     """
@@ -47,13 +48,14 @@ class DatabaseManager:
                 self.connection_type = None
                 self.database_path = None  # Clear the database path
     
-    def open_database(self, filename):
+    def open_database(self, filename, load_all_tables=True):
         """
         Open a database connection to the specified file.
         Detects whether it's a SQLite or DuckDB database.
         
         Args:
             filename: Path to the database file
+            load_all_tables: Whether to automatically load all tables from the database
             
         Returns:
             True if successful, False otherwise
@@ -64,6 +66,10 @@ class DatabaseManager:
         # Close any existing connection
         self.close_connection()
         
+        # Clear any existing loaded tables
+        self.loaded_tables = {}
+        self.table_columns = {}
+        
         try:
             if self.is_sqlite_db(filename):
                 self.conn = sqlite3.connect(filename)
@@ -75,8 +81,9 @@ class DatabaseManager:
             # Store the database path
             self.database_path = os.path.abspath(filename)
             
-            # Load tables from the database
-            self.load_database_tables()
+            # Load tables from the database if requested
+            if load_all_tables:
+                self.load_database_tables()
             return True
         except (sqlite3.Error, duckdb.Error) as e:
             self.conn = None
@@ -212,7 +219,7 @@ class DatabaseManager:
         Load data from a file into the database.
         
         Args:
-            file_path: Path to the data file (Excel, CSV, Parquet)
+            file_path: Path to the data file (Excel, CSV, Parquet, Delta)
             
         Returns:
             Tuple of (table_name, DataFrame) for the loaded data
@@ -221,8 +228,23 @@ class DatabaseManager:
             ValueError: If the file format is unsupported or there's an error
         """
         try:
+            # Check if this is a Delta table (folder with _delta_log)
+            delta_path = Path(file_path)
+            is_delta_table = (delta_path.is_dir() and 
+                             (delta_path / '_delta_log').exists()) or file_path.endswith('.delta')
+            
             # Read the file into a DataFrame, using optimized loading strategies
-            if file_path.endswith(('.xlsx', '.xls')):
+            if is_delta_table:
+                # Read as Delta table using deltalake library
+                try:
+                    # Load the Delta table
+                    import deltalake
+                    delta_table = deltalake.DeltaTable(file_path)
+                    # Convert to pandas DataFrame
+                    df = delta_table.to_pandas()
+                except Exception as e:
+                    raise ValueError(f"Error loading Delta table: {str(e)}")
+            elif file_path.endswith(('.xlsx', '.xls')):
                 # Try to use a streaming approach for Excel files
                 try:
                     # For Excel files, we first check if it's a large file
@@ -279,6 +301,11 @@ class DatabaseManager:
             
             # Generate table name from file name
             base_name = os.path.splitext(os.path.basename(file_path))[0]
+            
+            # For directories like Delta tables, use the directory name
+            if os.path.isdir(file_path):
+                base_name = os.path.basename(file_path)
+                
             table_name = self.sanitize_table_name(base_name)
             
             # Ensure unique table name
@@ -374,6 +401,68 @@ class DatabaseManager:
         except Exception as e:
             raise Exception(f"Error previewing table: {str(e)}")
     
+    def reload_table(self, table_name):
+        """
+        Reload a table's data from its source file.
+        
+        Args:
+            table_name: Name of the table to reload
+            
+        Returns:
+            Tuple of (bool, message) indicating success/failure and a message
+            
+        Raises:
+            ValueError: If the table cannot be reloaded
+        """
+        if not table_name in self.loaded_tables:
+            return False, f"Table '{table_name}' not found"
+        
+        file_path = self.loaded_tables[table_name]
+        
+        # Check if this is a file-based table
+        if file_path in ['database', 'query_result']:
+            return False, f"Cannot reload '{table_name}' because it's not a file-based table"
+        
+        try:
+            # Check if the file still exists
+            if not os.path.exists(file_path):
+                return False, f"Source file '{file_path}' no longer exists"
+            
+            # Store the original table name
+            original_name = table_name
+            
+            # Remove the existing table
+            self.remove_table(table_name)
+            
+            # Check if this is a Delta table
+            delta_path = Path(file_path)
+            is_delta_table = (delta_path.is_dir() and 
+                             (delta_path / '_delta_log').exists()) or file_path.endswith('.delta')
+            
+            # Load the file with the original table name
+            df = None
+            if is_delta_table:
+                # Read as Delta table
+                import deltalake
+                delta_table = deltalake.DeltaTable(file_path)
+                df = delta_table.to_pandas()
+            elif file_path.endswith(('.xlsx', '.xls')):
+                df = pd.read_excel(file_path)
+            elif file_path.endswith('.csv'):
+                df = pd.read_csv(file_path)
+            elif file_path.endswith('.parquet'):
+                df = pd.read_parquet(file_path)
+            else:
+                return False, "Unsupported file format"
+            
+            # Register the dataframe with the original name
+            self.register_dataframe(df, original_name, file_path)
+            
+            return True, f"Table '{table_name}' reloaded successfully"
+            
+        except Exception as e:
+            return False, f"Error reloading table: {str(e)}"
+    
     def rename_table(self, old_name, new_name):
         """
         Rename a table in the database.
@@ -688,4 +777,61 @@ class DatabaseManager:
                     column_data_types[col_name] = data_type
         except Exception:
             # Ignore errors in type detection - this is just for enhancement
-            pass 
\ No newline at end of file
+            pass 
+    
+    def load_specific_table(self, table_name):
+        """
+        Load metadata for a specific table from the database.
+        This is used when we know which tables we want to load rather than loading all tables.
+        
+        Args:
+            table_name: Name of the table to load
+            
+        Returns:
+            Boolean indicating if the table was found and loaded
+        """
+        if not self.is_connected():
+            return False
+            
+        try:
+            if self.connection_type == 'sqlite':
+                # Check if the table exists in SQLite
+                cursor = self.conn.cursor()
+                cursor.execute("SELECT name FROM sqlite_master WHERE type='table' AND name=?", (table_name,))
+                result = cursor.fetchone()
+                
+                if result:
+                    # Get column names for the table
+                    try:
+                        column_query = f"PRAGMA table_info({table_name})"
+                        columns = cursor.execute(column_query).fetchall()
+                        self.table_columns[table_name] = [col[1] for col in columns]  # Column name is at index 1
+                    except Exception:
+                        self.table_columns[table_name] = []
+                    
+                    # Register the table
+                    self.loaded_tables[table_name] = 'database'
+                    return True
+                    
+            else:  # duckdb
+                # Check if the table exists in DuckDB
+                query = f"SELECT table_name FROM information_schema.tables WHERE table_name='{table_name}' AND table_schema='main'"
+                result = self.conn.execute(query).fetchdf()
+                
+                if not result.empty:
+                    # Get column names for the table
+                    try:
+                        column_query = f"SELECT column_name FROM information_schema.columns WHERE table_name='{table_name}' AND table_schema='main'"
+                        columns = self.conn.execute(column_query).fetchdf()
+                        self.table_columns[table_name] = columns['column_name'].tolist()
+                    except Exception:
+                        self.table_columns[table_name] = []
+                    
+                    # Register the table
+                    self.loaded_tables[table_name] = 'database'
+                    return True
+            
+            return False
+            
+        except Exception:
+            return False 
\ No newline at end of file
